Focus Issue

Context Menu
Disabled Item
Cut
Copy
Paste
Enabled Submenu
Submenu Item One
Submenu Item Two
Deeper Submenu
Sub-sub-menu Item One
Sub-sub-menu Item Two
Disabled Submenu
Submenu Item One
Submenu Item Two
Checked
Not Checked
Checked Disabled
Bigger Submenu
Item One
Item Two
Item Three
Item Four
Item Five
Item Six
Item Seven
Item Eight
Item Nine
Item Ten

To test:

- Right mouse click anywhere on the page to see the context menu
- Mouse-over "Enabled Submenu"
- Make sure the submenu is positioned properly